@@ -8,6 +8,7 @@
 
 import dispatch
 
+mueve_camara = dispatch.Signal(providing_args=['x', 'y', 'dx', 'dy'])
 mueve_mouse = dispatch.Signal(providing_args=['x', 'y', 'dx', 'dy'])
 click_de_mouse = dispatch.Signal(providing_args=['button', 'x', 'y'])
 termina_click = dispatch.Signal(providing_args=['button', 'x', 'y'])
@@ -16,6 +17,7 @@ pulsa_tecla = dispatch.Signal(providing_args=['codigo', 'texto'])
 suelta_tecla = dispatch.Signal(providing_args=['codigo', 'texto'])
 pulsa_tecla_escape = dispatch.Signal(providing_args=[])
 actualizar = dispatch.Signal(providing_args=[])
+actualizar_pausado = dispatch.Signal(providing_args=[])
 post_dibujar = dispatch.Signal(providing_args=[])
 
 # Se emite cuando el mundo ingresa o sale del modo depuracion (pulsando F12)
